# -*- encoding=utf-8 -*-
# This file was generated automatically

__version__ = (5,1,8,1129)

def start():
    try:
        print("testproject v"+".".join(str(x) for x in __version__))
        # YOUR CODE HERE
        pass
    except KeyboardInterrupt:
        pass

if __name__ == "__main__":
    start()
                